@@ -85,95 +85,88 @@ func TestIntegration(t *testing.T) {
 			stderr:  "Failed to load configurations;",
 		},
 		{
-			name:    "removed `debug` options",
+			name:    "removed --debug options",
 			command: "./tflint --debug",
 			dir:     "no_issues",
 			status:  cmd.ExitCodeError,
-			stderr:  "`debug` option was removed in v0.8.0. Please set `TFLINT_LOG` environment variables instead",
+			stderr:  "--debug option was removed in v0.8.0. Please set TFLINT_LOG environment variables instead",
 		},
 		{
-			name:    "removed `fast` option",
-			command: "./tflint --fast",
-			dir:     "no_issues",
-			status:  cmd.ExitCodeError,
-			stderr:  "`fast` option was removed in v0.9.0. The `aws_instance_invalid_ami` rule is already fast enough",
-		},
-		{
-			name:    "removed `--error-with-issues` option",
+			name:    "removed --error-with-issues option",
 			command: "./tflint --error-with-issues",
 			dir:     "no_issues",
 			status:  cmd.ExitCodeError,
-			stderr:  "`error-with-issues` option was removed in v0.9.0. The behavior is now default",
+			stderr:  "--error-with-issues option was removed in v0.9.0. The behavior is now default",
 		},
 		{
-			name:    "removed `--quiet` option",
+			name:    "removed --quiet option",
 			command: "./tflint --quiet",
 			dir:     "no_issues",
 			status:  cmd.ExitCodeError,
-			stderr:  "`quiet` option was removed in v0.11.0. The behavior is now default",
+			stderr:  "--quiet option was removed in v0.11.0. The behavior is now default",
 		},
 		{
-			name:    "removed `--ignore-rule` option",
+			name:    "removed --ignore-rule option",
 			command: "./tflint --ignore-rule aws_instance_example_type",
 			dir:     "no_issues",
 			status:  cmd.ExitCodeError,
-			stderr:  "`ignore-rule` option was removed in v0.12.0. Please use `--disable-rule` instead",
+			stderr:  "--ignore-rule option was removed in v0.12.0. Please use --disable-rule instead",
 		},
 		{
-			name:    "removed `--deep` option",
+			name:    "removed --deep option",
 			command: "./tflint --deep",
 			dir:     "no_issues",
 			status:  cmd.ExitCodeError,
-			stderr:  "`deep` option was removed in v0.23.0. Deep checking is now a feature of the AWS plugin, so please configure the plugin instead",
+			stderr:  "--deep option was removed in v0.23.0. Deep checking is now a feature of the AWS plugin, so please configure the plugin instead",
 		},
 		{
-			name:    "removed `--aws-access-key` option",
+			name:    "removed --aws-access-key option",
 			command: "./tflint --aws-access-key AWS_ACCESS_KEY_ID",
 			dir:     "no_issues",
 			status:  cmd.ExitCodeError,
-			stderr:  "`aws-access-key` option was removed in v0.23.0. AWS rules are provided by the AWS plugin, so please configure the plugin instead",
+			stderr:  "--aws-access-key option was removed in v0.23.0. AWS rules are provided by the AWS plugin, so please configure the plugin instead",
 		},
 		{
-			name:    "removed `--aws-secret-key` option",
+			name:    "removed --aws-secret-key option",
 			command: "./tflint --aws-secret-key AWS_SECRET_ACCESS_KEY",
 			dir:     "no_issues",
 			status:  cmd.ExitCodeError,
-			stderr:  "`aws-secret-key` option was removed in v0.23.0. AWS rules are provided by the AWS plugin, so please configure the plugin instead",
+			stderr:  "--aws-secret-key option was removed in v0.23.0. AWS rules are provided by the AWS plugin, so please configure the plugin instead",
 		},
 		{
-			name:    "removed `--aws-profile` option",
+			name:    "removed --aws-profile option",
 			command: "./tflint --aws-profile AWS_PROFILE",
 			dir:     "no_issues",
 			status:  cmd.ExitCodeError,
-			stderr:  "`aws-profile` option was removed in v0.23.0. AWS rules are provided by the AWS plugin, so please configure the plugin instead",
+			stderr:  "--aws-profile option was removed in v0.23.0. AWS rules are provided by the AWS plugin, so please configure the plugin instead",
 		},
 		{
-			name:    "removed `--aws-creds-file` option",
+			name:    "removed --aws-creds-file option",
 			command: "./tflint --aws-creds-file FILE",
 			dir:     "no_issues",
 			status:  cmd.ExitCodeError,
-			stderr:  "`aws-creds-file` option was removed in v0.23.0. AWS rules are provided by the AWS plugin, so please configure the plugin instead",
+			stderr:  "--aws-creds-file option was removed in v0.23.0. AWS rules are provided by the AWS plugin, so please configure the plugin instead",
 		},
 		{
-			name:    "removed `--aws-region` option",
+			name:    "removed --aws-region option",
 			command: "./tflint --aws-region us-east-1",
 			dir:     "no_issues",
 			status:  cmd.ExitCodeError,
-			stderr:  "`aws-region` option was removed in v0.23.0. AWS rules are provided by the AWS plugin, so please configure the plugin instead",
+			stderr:  "--aws-region option was removed in v0.23.0. AWS rules are provided by the AWS plugin, so please configure the plugin instead",
 		},
 		{
-			name:    "removed `--loglevel` option",
+			name:    "removed --loglevel option",
 			command: "./tflint --loglevel debug",
 			dir:     "no_issues",
 			status:  cmd.ExitCodeError,
-			stderr:  "`loglevel` option was removed in v0.40.0. Please set `TFLINT_LOG` environment variables instead",
+			stderr:  "--loglevel option was removed in v0.40.0. Please set TFLINT_LOG environment variables instead",
 		},
 		{
 			name:    "invalid options",
 			command: "./tflint --unknown",
 			dir:     "no_issues",
 			status:  cmd.ExitCodeError,
-			stderr:  "`unknown` is unknown option. Please run `tflint --help`",
+			stderr:  `--unknown is unknown option. Please run "tflint --help"`,
 		},
 		{
 			name:    "invalid format",
@@ -197,35 +190,35 @@ func TestIntegration(t *testing.T) {
 			stdout:  fmt.Sprintf("%s (aws_instance_example_type)", color.New(color.Bold).Sprint("instance type is t2.micro")),
 		},
 		{
-			name:    "`--force` option with issues",
+			name:    "--force option with issues",
 			command: "./tflint --force",
 			dir:     "issues_found",
 			status:  cmd.ExitCodeOK,
 			stdout:  fmt.Sprintf("%s (aws_instance_example_type)", color.New(color.Bold).Sprint("instance type is t2.micro")),
 		},
 		{
-			name:    "`--minimum-failure-severity` option with warning issues and minimum-failure-severity notice",
+			name:    "--minimum-failure-severity option with warning issues and minimum-failure-severity notice",
 			command: "./tflint --minimum-failure-severity=notice",
 			dir:     "warnings_found",
 			status:  cmd.ExitCodeIssuesFound,
 			stdout:  fmt.Sprintf("%s (aws_s3_bucket_with_config_example)", color.New(color.Bold).Sprint("bucket name is test, config=bucket")),
 		},
 		{
-			name:    "`--minimum-failure-severity` option with warning issues and minimum-failure-severity warning",
+			name:    "--minimum-failure-severity option with warning issues and minimum-failure-severity warning",
 			command: "./tflint --minimum-failure-severity=warning",
 			dir:     "warnings_found",
 			status:  cmd.ExitCodeIssuesFound,
 			stdout:  fmt.Sprintf("%s (aws_s3_bucket_with_config_example)", color.New(color.Bold).Sprint("bucket name is test, config=bucket")),
 		},
 		{
-			name:    "`--minimum-failure-severity` option with warning issues and minimum-failure-severity error",
+			name:    "--minimum-failure-severity option with warning issues and minimum-failure-severity error",
 			command: "./tflint --minimum-failure-severity=error",
 			dir:     "warnings_found",
 			status:  cmd.ExitCodeOK,
 			stdout:  fmt.Sprintf("%s (aws_s3_bucket_with_config_example)", color.New(color.Bold).Sprint("bucket name is test, config=bucket")),
 		},
 		{
-			name:    "`--no-color` option",
+			name:    "--no-color option",
 			command: "./tflint --no-color",
 			dir:     "issues_found",
 			status:  cmd.ExitCodeIssuesFound,
